@@ -1,12 +1,12 @@
 package File::Trash::Undoable;
 
-our $DATE = '2015-02-06'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use File::MoreUtil qw(l_abs_path);
 use File::Trash::FreeDesktop;
@@ -243,7 +243,7 @@ File::Trash::Undoable - Trash files, with undo/redo capability
 
 =head1 VERSION
 
-This document describes version 0.16 of File::Trash::Undoable (from Perl distribution File-Trash-Undoable), released on 2015-02-06.
+This document describes version 0.17 of File::Trash::Undoable (from Perl distribution File-Trash-Undoable), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -504,7 +504,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/File-Trash
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-File-Trash-Undoable>.
+Source repository is at L<https://github.com/sharyanto/perl-File-Trash-Undoable>.
 
 =head1 BUGS
 
